@@ -1,8 +1,10 @@
+import logging
 from asyncio import run
 from PGram import Bot
 from loader import TOKEN
 from example.router import r
 
 """ Basic example """
-bot = Bot(TOKEN, routers=[r])
-run(bot.start())
+logging.getLogger().setLevel(logging.INFO)
+bot = Bot(TOKEN)
+run(bot.start([r]))
